@@ -56,11 +56,8 @@ sub isns_die {
 
 sub isns_finish {
 
-	my $pid_str;
 	my $pid;
-    
-	foreach $pid_str (@__isns_servers) {
-		$pid = $pid_str + 0;
+	foreach $pid (@__isns_servers) {
 		kill 15, $pid or &isns_warn("Cannot kill server process (pid=$pid): $!\n");
 	}
 
@@ -307,7 +304,7 @@ sub isns_start_server {
 				last if (-f $pidfile);
 				sleep 1;
 			}
-			$pid = `cat $pidfile`;
+			$pid = `cat $pidfile` if ($pidfile);
 			chop($pid);
 		}
 		&isns_info("*** Started server (pid=$pid) ***\n");
@@ -349,9 +346,6 @@ sub isns_restart_server {
 	$server_config = shift(@_);
 
 	&isns_stop_server($pid);
-	# give it some time to stop
-	&isns_idle(5);
-
 	return &isns_start_server($server_config);
 }
 
@@ -380,7 +374,6 @@ sub isns_verify_db {
 	# doesn't, this means we're priming the test case.
 	# Just copy the dump file.
 	$data_file = "$__isns_test_data/$stage";
-	$data_file = "${data_file}-no-security"	unless ($__isns_security);
 	unless (-f $data_file) {
 		print "*** Saving database dump for stage $stage ***\n";
 		mkdir $__isns_test_data, 0755;
@@ -420,7 +413,6 @@ sub verify_response {
 	# doesn't, this means we're priming the test case.
 	# Just copy the dump file.
 	$data_file = "$__isns_test_data/$stage";
-	$data_file = "${data_file}-no-security"	unless ($__isns_security);
 	unless (-f $data_file) {
 		print "*** Saving data for stage $stage ***\n";
 		mkdir $__isns_test_data, 0755;
